@@ -8,6 +8,7 @@ import re
 import sys
 from collections import namedtuple
 from contextlib import contextmanager
+from contextlib import suppress
 from functools import partial
 
 from . import fast_data_types as defines
@@ -19,19 +20,7 @@ from .conf.utils import (
 from .config_data import all_options, parse_mods, type_map
 from .constants import cache_dir, defconf, is_macos
 from .utils import log_error
-
-named_keys = {
-    "'": 'APOSTROPHE',
-    ',': 'COMMA',
-    '-': 'MINUS',
-    '.': 'PERIOD',
-    '/': 'SLASH',
-    ';': 'SEMICOLON',
-    '=': 'EQUAL',
-    '[': 'LEFT_BRACKET',
-    ']': 'RIGHT_BRACKET',
-    '`': 'GRAVE_ACCENT'
-}
+from .key_names import get_key_name_lookup, key_name_aliases
 
 
 def parse_shortcut(sc):
@@ -42,16 +31,15 @@ def parse_shortcut(sc):
         if mods is None:
             return None, None, None
     key = parts[-1].upper()
-    key = getattr(defines, 'GLFW_KEY_' + named_keys.get(key, key), None)
+    key = getattr(defines, 'GLFW_KEY_' + key_name_aliases.get(key, key), None)
     is_native = False
     if key is None:
-        if parts[-1].startswith('0x'):
-            try:
-                key = int(parts[-1], 16)
-            except Exception:
-                pass
+        q = parts[-1]
+        if q.startswith('0x'):
+            with suppress(Exception):
+                key = int(q, 16)
         else:
-            key = defines.key_for_native_key_name(parts[-1])
+            key = get_key_name_lookup()(q)
         is_native = key is not None
     return mods, is_native, key
 
@@ -261,6 +249,21 @@ class KeyDefinition:
         self.trigger = defines.resolve_key_mods(kitty_mod, self.trigger[0]), self.trigger[1], self.trigger[2]
         self.rest = tuple((defines.resolve_key_mods(kitty_mod, mods), is_native, key) for mods, is_native, key in self.rest)
 
+    def resolve_kitten_aliases(self, aliases):
+        if not self.action.args:
+            return
+        kitten = self.action.args[0]
+        rest = self.action.args[1] if len(self.action.args) > 1 else ''
+        changed = False
+        for key, expanded in aliases.items():
+            if key == kitten:
+                changed = True
+                kitten = expanded[0]
+                if len(expanded) > 1:
+                    rest = expanded[1] + ' ' + rest
+        if changed:
+            self.action = self.action._replace(args=[kitten + (' ' + rest).rstrip()])
+
 
 def parse_key(val, key_definitions):
     parts = val.split(maxsplit=1)
@@ -383,6 +386,13 @@ def handle_symbol_map(key, val, ans):
     ans['symbol_map'].update(parse_symbol_map(val))
 
 
+@special_handler
+def handle_kitten_alias(key, val, ans):
+    parts = val.split(maxsplit=2)
+    if len(parts) >= 2:
+        ans['kitten_aliases'][parts[0]] = parts[1:]
+
+
 @special_handler
 def handle_send_text(key, val, ans):
     # For legacy compatibility
@@ -401,7 +411,27 @@ def handle_deprecated_hide_window_decorations_aliases(key, val, ans):
         handle_deprecated_hide_window_decorations_aliases.key = True
         log_error('The option {} is deprecated. Use hide_window_decorations instead.'.format(key))
     if to_bool(val):
-        ans['hide_window_decorations'] = True
+        if is_macos and key == 'macos_hide_titlebar' or (not is_macos and key == 'x11_hide_window_decorations'):
+            ans['hide_window_decorations'] = True
+
+
+@deprecated_handler('macos_show_window_title_in_menubar')
+def handle_deprecated_macos_show_window_title_in_menubar_alias(key, val, ans):
+    if not hasattr(handle_deprecated_macos_show_window_title_in_menubar_alias, key):
+        handle_deprecated_macos_show_window_title_in_menubar_alias.key = True
+        log_error('The option {} is deprecated. Use macos_show_window_title_in menubar instead.'.format(key))
+    macos_show_window_title_in = ans.get('macos_show_window_title_in', 'all')
+    if to_bool(val):
+        if macos_show_window_title_in == 'none':
+            macos_show_window_title_in = 'menubar'
+        elif macos_show_window_title_in == 'window':
+            macos_show_window_title_in = 'all'
+    else:
+        if macos_show_window_title_in == 'all':
+            macos_show_window_title_in = 'window'
+        elif macos_show_window_title_in == 'menubar':
+            macos_show_window_title_in = 'none'
+    ans['macos_show_window_title_in'] = macos_show_window_title_in
 
 
 def expandvars(val, env):
@@ -441,7 +471,7 @@ def option_names_for_completion():
 
 
 def parse_config(lines, check_keys=True, accumulate_bad_lines=None):
-    ans = {'symbol_map': {}, 'keymap': {}, 'sequence_map': {}, 'key_definitions': [], 'env': {}}
+    ans = {'symbol_map': {}, 'keymap': {}, 'sequence_map': {}, 'key_definitions': [], 'env': {}, 'kitten_aliases': {}}
     parse_config_base(
         lines,
         defaults,
@@ -577,10 +607,8 @@ def commented_out_default_config():
 def prepare_config_file_for_editing():
     if not os.path.exists(defconf):
         d = os.path.dirname(defconf)
-        try:
+        with suppress(FileExistsError):
             os.makedirs(d)
-        except FileExistsError:
-            pass
         with open(defconf, 'w', encoding='utf-8') as f:
             f.write(commented_out_default_config())
     return defconf
@@ -593,8 +621,11 @@ def finalize_keys(opts):
             defns = []
         else:
             defns.append(d)
+    kitten_aliases = opts.kitten_aliases
     for d in defns:
         d.resolve(opts.kitty_mod)
+        if kitten_aliases and d.action.func == 'kitten':
+            d.resolve_kitten_aliases(kitten_aliases)
     keymap = {}
     sequence_map = {}
 
@@ -628,6 +659,4 @@ def load_config(*paths, overrides=None, accumulate_bad_lines=None):
     if opts.background_opacity < 1.0 and opts.macos_titlebar_color:
         log_error('Cannot use both macos_titlebar_color and background_opacity')
         opts.macos_titlebar_color = 0
-    if (is_macos and getattr(opts, 'macos_hide_titlebar', False)) or (not is_macos and getattr(opts, 'x11_hide_window_decorations', False)):
-        opts.hide_window_decorations = True
     return opts
