@@ -112,7 +112,9 @@ Here, the key name for the :kbd:`A` key is :kbd:`0x61` and you can use it with::
 to map :kbd:`ctrl+a` to something.
 
 You can use the special action :code:`no_op` to unmap a keyboard shortcut that is
-assigned in the default configuration.
+assigned in the default configuration::
+
+    map kitty_mod+space no_op
 
 You can combine multiple actions to be triggered by a single shortcut, using the
 syntax below::
@@ -456,9 +458,12 @@ o('rectangle_select_modifiers', 'ctrl+alt', option_type=to_modifiers, long_text=
 The modifiers to use rectangular selection (i.e. to select text in a
 rectangular block with the mouse)'''))
 
+o('terminal_select_modifiers', 'shift', option_type=to_modifiers, long_text=_('''
+The modifiers to override mouse selection even when a terminal application has grabbed the mouse'''))
+
 o('select_by_word_characters', ':@-./_~?&=%+#', long_text=_('''
 Characters considered part of a word when double clicking. In addition to these characters
-any character that is marked as an alpha-numeric character in the unicode
+any character that is marked as an alphanumeric character in the unicode
 database will be matched.'''))
 
 o('click_interval', -1.0, option_type=float, long_text=_('''
@@ -469,6 +474,10 @@ o('focus_follows_mouse', False, long_text=_('''
 Set the active window to the window under the mouse when
 moving the mouse around'''))
 
+o('pointer_shape_when_grabbed', 'arrow', option_type=choices('arrow', 'beam', 'hand'), long_text=('''
+The shape of the mouse pointer when the program running in the terminal grabs the mouse.
+'''))
+
 # }}}
 
 g('performance')  # {{{
@@ -478,7 +487,8 @@ Delay (in milliseconds) between screen updates. Decreasing it, increases
 frames-per-second (FPS) at the cost of more CPU usage. The default value
 yields ~100 FPS which is more than sufficient for most uses. Note that to
 actually achieve 100 FPS you have to either set :opt:`sync_to_monitor` to no
-or use a monitor with a high refresh rate.'''))
+or use a monitor with a high refresh rate. Also, to minimize latency
+when there is pending input to be processed, repaint_delay is ignored.'''))
 
 o('input_delay', 3, option_type=positive_int, long_text=_('''
 Delay (in milliseconds) before input from the program running in the terminal
@@ -513,6 +523,9 @@ o('bell_on_tab', True, long_text=_('''
 Show a bell symbol on the tab if a bell occurs in one of the windows in the
 tab and the window is not the currently focused window'''))
 
+o('command_on_bell', 'none', option_type=to_cmdline, long_text=_('''
+Program to run when a bell occurs.
+'''))
 # }}}
 
 g('window')  # {{{
@@ -583,6 +596,14 @@ Negative values will cause the value of :opt:`window_margin_width` to be used in
 o('window_padding_width', 0.0, option_type=positive_float, long_text=_('''
 The window padding (in pts) (blank area between the text and the window border)'''))
 
+o('placement_strategy', 'center', option_type=choices('center', 'top-left'), long_text=_('''
+When the window size is not an exact multiple of the cell size, the cell area of the terminal
+window will have some extra padding on the sides. You can control how that padding is
+distributed with this option. Using a value of :code:`center` means the cell area will
+be placed centrally. A value of :code:`top-left` means the padding will be on only
+the bottom and right edges.
+'''))
+
 o('active_border_color', '#00ff00', option_type=to_color_or_none, long_text=_('''
 The color for the border of the active window. Set this to none to not draw borders
 around the active window.'''))
@@ -607,7 +628,7 @@ window manager/operating system.
 o('resize_debounce_time', 0.1, option_type=positive_float, long_text=_('''
 The time (in seconds) to wait before redrawing the screen when a
 resize event is received. On platforms such as macOS, where the
-operating system sends event corresponding to the start and end
+operating system sends events corresponding to the start and end
 of a resize, this number is ignored.'''))
 
 
@@ -825,7 +846,7 @@ environment variables are expanded recursively, so if you use::
 The value of MYVAR2 will be :code:`a/<path to home directory>/b`.
 '''))
 
-o('update_check_interval', 24, option_type=float, long_text=_('''
+o('update_check_interval', 0.0, option_type=float, long_text=_('''
 Periodically check if an update to kitty is available. If an update is found
 a system notification is displayed informing you of the available update.
 The default is to check every 24 hrs, set to zero to disable.
@@ -945,15 +966,27 @@ o('macos_traditional_fullscreen', False, long_text=_('''
 Use the traditional full-screen transition, that is faster, but less pretty.
 '''))
 
-o('macos_show_window_title_in_menubar', True, long_text=_('''
-Show the title of the currently active window in the macOS
-menu-bar, making use of otherwise wasted space.'''))
+o('macos_show_window_title_in', 'all', option_type=choices('all', 'window', 'menubar', 'none'), long_text=_('''
+Show or hide the window title in the macOS window or menu-bar.
+A value of :code:`window` will show the title of the currently
+active window at the top of the macOS window. A value of
+:code:`menubar` will show the title of the currently active window
+in the macOS menu-bar, making use of otherwise wasted space.
+:code:`all` will show the title everywhere and :code:`none`
+hides the title in the window and the menu-bar.
+'''))
 
 # Disabled by default because of https://github.com/kovidgoyal/kitty/issues/794
 o('macos_custom_beam_cursor', False, long_text=_('''
 Enable/disable custom mouse cursor for macOS that is easier to see on both
 light and dark backgrounds. WARNING: this might make your mouse cursor
 invisible on dual GPU machines.'''))
+
+o('linux_display_server', 'auto', option_type=choices('auto', 'x11', 'wayland'), long_text=_('''
+Choose between Wayland and X11 backends. By default, an
+appropriate backend based on the system state is chosen
+automatically. Set it to :code:`x11` or :code:`wayland`
+to force the choice.'''))
 # }}}
 
 g('shortcuts')  # {{{
@@ -967,6 +1000,14 @@ o('clear_all_shortcuts', False, long_text=_('''
 You can have kitty remove all shortcut definition seen up to this point. Useful, for
 instance, to remove the default shortcuts.'''))
 
+o('kitten_alias', 'hints hints --hints-offset=0', add_to_default=False, long_text=_('''
+You can create aliases for kitten names, this allows overriding the defaults
+for kitten options and can also be used to shorten repeated mappings of the same
+kitten with a specific group of options. For example, the above alias
+changes the default value of :option:`kitty +kitten hints --hints-offset`
+to zero for all mappings, including the builtin ones.
+'''))
+
 g('shortcuts.clipboard')  # {{{
 k('copy_to_clipboard', 'kitty_mod+c', 'copy_to_clipboard', _('Copy to clipboard'), long_text=_('''
 There is also a :code:`copy_or_interrupt` action that can be optionally mapped to :kbd:`Ctrl+c`.
@@ -981,7 +1022,8 @@ k('paste_from_selection', 'shift+insert', 'paste_from_selection', _('Paste from
 k('pass_selection_to_program', 'kitty_mod+o', 'pass_selection_to_program', _('Pass selection to program'), long_text=_('''
 You can also pass the contents of the current selection to any program using
 :code:`pass_selection_to_program`. By default, the system's open program is used, but
-you can specify your own, for example::
+you can specify your own, the selection will be passed as a command line argument to the program,
+for example::
 
     map kitty_mod+o pass_selection_to_program firefox
 
@@ -1048,10 +1090,19 @@ Any programs running in that window will be allowed to control kitty.
 For example::
 
     map ctrl+enter new_window @ some_program
+
+You can open a new window next to the currently active window or as the first window,
+with::
+
+    map ctrl+n new_window !neighbor some_program
+    map ctrl+f new_window !first some_program
+
 '''))
 if is_macos:
     k('new_window', 'cmd+enter', 'new_window', _('New window'), add_to_docs=False)
-k('new_os_window', 'kitty_mod+n', 'new_os_window', _('New OS window'))
+k('new_os_window', 'kitty_mod+n', 'new_os_window', _('New OS window'), _(
+    'Works like new_window above, except that it opens a top level OS kitty window.'
+    ' In particular you can use new_os_window_with_cwd to open a window with the current working directory.'))
 if is_macos:
     k('new_os_window', 'cmd+n', 'new_os_window', _('New OS window'), add_to_docs=False)
 k('close_window', 'kitty_mod+w', 'close_window', _('Close window'))
@@ -1154,6 +1205,7 @@ Useful with git, which uses sha1 hashes to identify commits'''))
 
 g('shortcuts.misc')  # {{{
 k('toggle_fullscreen', 'kitty_mod+f11', 'toggle_fullscreen', _('Toggle fullscreen'))
+k('toggle_maximized', 'kitty_mod+f10', 'toggle_maximized', _('Toggle maximized'))
 k('input_unicode_character', 'kitty_mod+u', 'kitten unicode_input', _('Unicode input'))
 k('edit_config_file', 'kitty_mod+f2', 'edit_config_file', _('Edit config file'))
 k('kitty_shell', 'kitty_mod+escape', 'kitty_shell window', _('Open the kitty command shell'), long_text=_('''
@@ -1175,7 +1227,7 @@ You can create shortcuts to clear/reset the terminal. For example::
     # Scroll the contents of the screen into the scrollback
     map kitty_mod+f12 clear_terminal scroll active
 
-If you want to operate on all windows instead of just the current one, use :italic:`all` instead of :italic`active`.
+If you want to operate on all windows instead of just the current one, use :italic:`all` instead of :italic:`active`.
 
 It is also possible to remap Ctrl+L to both scroll the current screen contents into the scrollback buffer
 and clear the screen, instead of just clearing the screen::
